2.7
===

Updated skeleton and added a couple quips.

2.6
===

Moved hosting to Github with automated deployments by Travis-CI.

Fixed issue where ``!norris #channel`` would fail with a KeyError.

2.5
===

Gender lookups through genderize.io are now cached indefinitely
in memory.

2.4
===

The ChuckNorris library is now mostly gender-neutral.
